@@ -16,8 +16,6 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-
-from __future__ import absolute_import
 from unittest import mock
 
 from django.conf import settings
@@ -795,7 +793,7 @@ class ComputeApiTests(test.APIMockTestCase):
 
         self.assertIsInstance(ret, api.nova.Server)
         self.mock_get_microversion.assert_called_once_with(
-            mock.sentinel.request, ('multiattach', 'instance_description',
+            mock.sentinel.request, ('instance_description',
                                     'auto_allocated_network'))
         self.mock_novaclient.assert_called_once_with(
             mock.sentinel.request, version=mock.sentinel.microversion)
